import { geoAlbers, geoPath, geoGraticule } from 'd3';

const projection = geoAlbers();
const path = geoPath(projection);
const graticule = geoGraticule();

export const MapMarks = ({
  atlas: { land, interiors }, 
  capitals,
  cities,
  sizeScale,
  sizeValue,
  colorScale
}) => (
    <g className="marks">
      <path className="sphere" d={path({ type: 'Sphere' })} /> 
      <path className="graticules" d={path(graticule())} />
      {land.features.map((feature, index) => (
        <path className="land" d={path(feature)} fill={colorScale(index)}
        />
      ))}
      <path className="interiors" d={path(interiors)} />
      {capitals.map(d => {
        const [x, y] = projection([d.lon, d.lat]);
        return <circle className="capital" cx={x} cy={y} r={1.5} />;
      })}
      {cities.map(d => {
        const [x, y] = projection([d.lng, d.lat]);
        return <circle className="citiPop" cx={x} cy={y} r={sizeScale(sizeValue(d))} />;
      })}
    </g>
);
