import React from 'react';
import ReactDOM from 'react-dom';
import { scaleLinear, scaleSqrt, max } from 'd3';
import { getUsAtlas } from './getUsAtlas';
import { useCities, usCapCities } from './useCities';
import { MapMarks } from './MapMarks';

const width = 960;
const height = 500;

const App = () => {
  const atlasUs = getUsAtlas();
  const cities = useCities();
  const capitals = usCapCities();

  if (!atlasUs || !cities || !capitals) {
    return <pre>Loading...</pre>;
  }

  const colorScale = scaleLinear()
  	.domain([0,60])
  	.range(["white", "blue"]);

  const sizeValue1 = d => (d.population);
  const maxPop = max(cities, sizeValue1);
  console.log(maxPop);
  const sizeValue = d => {if(typeof d.population === 'undefined') 
  {return maxPop/4; } else { return d.population; }};
  console.log(sizeValue(capitals[0]));
  console.log(sizeValue(cities[10]));
  const maxRadius = 20;

  const sizeScale = scaleSqrt()
    .domain([0, max(cities, sizeValue)])
    .range([0, maxRadius]);
  
  console.log(cities[10]);
  const usCities = cities.filter(d => d['country'] === 'United States');
  console.log(capitals[0]);
  
  return (
    <svg width={width} height={height}>
      <MapMarks 
        atlas={atlasUs} 
        colorScale={colorScale}
        cities={usCities}
        capitals={capitals}
        sizeScale={sizeScale}
        sizeValue={sizeValue}
      />
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
